@@ -16,8 +16,10 @@ fn main() {
 
         // this would be a good usage for CheckedCommand ;=)
         let exit_status = Command::new(compiler)
-            .arg("--target").arg(target)
-            .arg("-o").arg(out_file)
+            .arg("--target")
+            .arg(target)
+            .arg("-o")
+            .arg(out_file)
             .arg(in_file)
             .status()
             .expect("failed to execute rustc");
@@ -26,4 +28,4 @@ fn main() {
             panic!("rustc failed with exit status {:?}", exit_status.code())
         }
     }
-}
\ No newline at end of file
+}
